| Title: | hdf5 library as an R package |
|---|---|
| Description: | Provides C and C++ hdf5 libraries. |
| Authors: | Mike Smith [ctb] (ORCID: <https://orcid.org/0000-0002-7800-3848>), Hugo Gruson [cre] (ORCID: <https://orcid.org/0000-0002-4094-1476>), The HDF Group [cph] |
| Maintainer: | Hugo Gruson <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 2.1.0 |
| Built: | 2026-05-30 05:31:29 UTC |
| Source: | https://github.com/bioc/Rhdf5lib |
This function returns the version number of the HDF5 library that is distributed with this package.
getHdf5Version()getHdf5Version()
Returns a character vector of length 1 containing the version
number.
getHdf5Version()getHdf5Version()
This function returns values for PKG_LIBS variables for use in
Makevars files.
pkgconfig( opt = c("PKG_CXX_LIBS", "PKG_C_LIBS", "PKG_CXX_HL_LIBS", "PKG_C_HL_LIBS") )pkgconfig( opt = c("PKG_CXX_LIBS", "PKG_C_LIBS", "PKG_CXX_HL_LIBS", "PKG_C_HL_LIBS") )
opt |
A scalar character from the list of available options;
default is |
NULL; prints the corresponding value to stdout.
pkgconfig("PKG_C_LIBS") pkgconfig("PKG_CXX_LIBS") pkgconfig("PKG_C_HL_LIBS") pkgconfig("PKG_CXX_HL_LIBS")pkgconfig("PKG_C_LIBS") pkgconfig("PKG_CXX_LIBS") pkgconfig("PKG_C_HL_LIBS") pkgconfig("PKG_CXX_HL_LIBS")
This package provides a compiled version of the HDF5 library bundled within the R package structure. It is primarily useful to developers of other R packages who want to make use of the capabilities of the HDF5 library directly in the C or C++ code of their own packages, rather than using a higher level interface.
Maintainer: Hugo Gruson [email protected] (ORCID)
Other contributors:
Mike Smith (ORCID) [contributor]
The HDF Group [copyright holder]
Useful links:
Report bugs at https://github.com/Huber-group-EMBL/Rhdf5lib/issues